Range-v3: Member List

Range-v3 Range algorithms, views, and actions for the Standard Library |

All Classes Files Functions Typedefs Modules Pages
ranges::v3::range_access Member List

This is the complete list of members for ranges::v3::range_access, including all inherited members.

advance(Cur &pos, D n) -> decltype(pos.advance(n)) (defined in ranges::v3::range_access) | ranges::v3::range_access | static
begin_adaptor(Rng &rng) -> decltype(rng.begin_adaptor()) (defined in ranges::v3::range_access) | ranges::v3::range_access | static
begin_cursor(Rng &rng) -> decltype(rng.begin_cursor()) (defined in ranges::v3::range_access) | ranges::v3::range_access | static
current(Cur const &pos) -> decltype(pos.current()) (defined in ranges::v3::range_access) | ranges::v3::range_access | static
cursor(basic_iterator< Cur, S > it) (defined in ranges::v3::range_access) | ranges::v3::range_access | static
cursor_difference_t typedef (defined in ranges::v3::range_access) | ranges::v3::range_access |
cursor_value_t typedef (defined in ranges::v3::range_access) | ranges::v3::range_access |
distance_to(Cur const &pos0, Cur const &pos1) -> decltype(pos0.distance_to(pos1)) (defined in ranges::v3::range_access) | ranges::v3::range_access | static
done(Cur const &pos) -> decltype(pos.done()) (defined in ranges::v3::range_access) | ranges::v3::range_access | static
empty(Cur const &pos, S const &end) -> decltype(end.equal(pos)) (defined in ranges::v3::range_access) | ranges::v3::range_access | static
end_adaptor(Rng &rng) -> decltype(rng.end_adaptor()) (defined in ranges::v3::range_access) | ranges::v3::range_access | static
end_cursor(Rng &rng) -> decltype(rng.end_cursor()) (defined in ranges::v3::range_access) | ranges::v3::range_access | static
equal(Cur const &pos0, Cur const &pos1) -> decltype(pos0.equal(pos1)) (defined in ranges::v3::range_access) | ranges::v3::range_access | static
next(Cur &pos) -> decltype(pos.next()) (defined in ranges::v3::range_access) | ranges::v3::range_access | static
prev(Cur &pos) -> decltype(pos.prev()) (defined in ranges::v3::range_access) | ranges::v3::range_access | static
sentinel(basic_sentinel< S > s) (defined in ranges::v3::range_access) | ranges::v3::range_access | static
single_pass_t typedef (defined in ranges::v3::range_access) | ranges::v3::range_access |